@@ -287,14 +287,8 @@ static XtActionsRec actions[] = {
 --------------------------------------------------------------*/
 
 static Boolean
-dummyCvtStringToPixmap(dpy, args, num_args, fromVal, toVal,converter_data)
-   Display   *dpy;
-   XrmValue  *args;
-   Cardinal  *num_args;
-   XrmValue  *fromVal;
-   XrmValue  *toVal;
-   XtPointer *converter_data;
-{   
+dummyCvtStringToPixmap(Display *dpy _GL_UNUSED, XrmValue *args _GL_UNUSED, Cardinal *num_args _GL_UNUSED, XrmValue *fromVal _GL_UNUSED, XrmValue *toVal _GL_UNUSED, XtPointer *converter_data _GL_UNUSED)
+{
    BEGINMESSAGE(dummyCvtStringToPixmap)
 #  ifdef MESSAGES
    {
@@ -327,9 +321,7 @@ void main_createScaleMenu(void);
    Main
 #################################################################################*/
 
-int main(argc, argv)
-  int  argc;
-  char *argv[];
+int main(int argc, char *argv[])
 {
   MAINBEGINMESSAGE(main)
   gv_safe_gs_workdir = GV_LIBDIR "/safe-gs-workdir";
@@ -702,7 +694,7 @@ int main(argc, argv)
         char buffer[512];
 	strcpy(buffer, app_res.scratch_dir);
 	strcat(buffer,"gv-safe-workdir-XXXXXX");
-	file_translateTildeInPath(buffer);
+	file_translateTildeInPath(buffer, sizeof(buffer));
         gv_safe_gs_workdir = strdup(mkdtemp(buffer));
 	gv_safe_gs_tempdir = 1;
 
@@ -721,7 +713,7 @@ int main(argc, argv)
        char* tmp_savepos_filename;
        main_setInternResource(gv_database,&tmp_savepos_filename,"saveposFilename");
        strcpy(gv_savepos_filename, tmp_savepos_filename);
-       file_translateTildeInPath(gv_savepos_filename);
+       file_translateTildeInPath(gv_savepos_filename, sizeof(gv_savepos_filename));
     }
     
     main_setInternResource(gv_database,&gv_uncompress_command,"uncompressCommand");
