@@ -162,9 +162,7 @@ static void options_setup_setOptionsAtEntry(void)
    options_setup_cb_apply
 ------------------------------------------------------*/
 
-static void options_setup_cb_apply(w, client_data, call_data)
-   Widget	w;
-   XtPointer	client_data, call_data;
+static void options_setup_cb_apply(Widget w _GL_UNUSED, XtPointer client_data _GL_UNUSED, XtPointer call_data _GL_UNUSED)
 {
    Arg args[5];
    Cardinal n;
@@ -306,9 +304,7 @@ static void options_setup_cb_apply(w, client_data, call_data)
 ------------------------------------------------------*/
 
 static
-void options_setup_cb_save(w, client_data, call_data)
-  Widget	w;
-  XtPointer	client_data, call_data;
+void options_setup_cb_save(Widget w _GL_UNUSED, XtPointer client_data _GL_UNUSED, XtPointer call_data _GL_UNUSED)
 {
   int    argn = 0;
   String argi[30];
