@@ -68,6 +68,7 @@
 #include <stdlib.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <math.h>
 
 #include <string.h>
 
@@ -112,24 +113,14 @@ extern int gv_infoSkipErrors;
 
 /* We use this helper function for providing proper */
 /* case and colon :-) insensitive DSC matching */
-static int dsc_strncmp(s1, s2, n)
-  char *s1;
-  char *s2;
-  size_t n;
+static int dsc_strncmp(const char *s1, const char *s2, size_t n)
 {
- char *tmp;	
-
  if (strncasecmp(s1, s2, n) == 0)
 	 return 0;
  if (s2[n-1] == ':'){
-	 tmp = (char *) malloc(n*sizeof(char));
-	 strncpy(tmp, s2, (n-1));
-	 tmp[n-1]=' ';
-	 if (strncasecmp(s1, tmp, n) == 0){
-		 free(tmp);
+	 if (strncasecmp(s1, s2, n-1) == 0 && s1[n-1] == ' ') {
 		 return 0;
 	 }
-	 free(tmp);
  }
  
  return 1;
@@ -141,6 +132,14 @@ static int dsc_strncmp(s1, s2, n)
 #define iscomment(a, b) (dsc_strncmp((a), (b), length((b))) == 0)
 #define DSCcomment(a)   ((a)[0] == '%' && (a)[1] == '%')
 
+static inline char *firstword(char *p) {
+	while (*p == ' ' || *p == '\t')
+		p++;
+	return p;
+}
+
+#define isword(a, b) ((strncmp((a), (b), length((b)))==0)?(a[length((b))] == ' ' || a[length((b))] == '\t' || a[length((b))] == '\n' || a[length((b))] == '\0'):0)
+
 /* list of standard paper sizes from Adobe's PPD. */
 
 #if 0
@@ -331,17 +330,46 @@ static void ps_dynMemExhaust(void)
 /* psscan */
 /*###########################################################*/
 
+static int parse_boundingbox(const char *l, int *boundingbox) {
+	const char *p = l;
+	double fllx, flly, furx, fury;
+	char *pe;
+
+	fllx = strtod(p, &pe);
+	if (*pe != ' ' && *pe != '\t') {
+		return 0;
+	}
+	p = pe;
+	while (*p == ' ' || *p == '\t')
+		p++;
+	flly = strtod(p, &pe);
+	if (*pe != ' ' && *pe != '\t') {
+		return 0;
+	}
+	p = pe;
+	while (*p == ' ' || *p == '\t')
+		p++;
+	furx = strtod(p, &pe);
+	if (*pe != ' ' && *pe != '\t') {
+		return 0;
+	}
+	p = pe;
+	while (*p == ' ' || *p == '\t')
+		p++;
+	fury = strtod(p, &pe);
+	if (*pe != '\n' && *pe != '\0' && *pe != ' ' && *pe != '\t') {
+		return 0;
+	}
+
+	boundingbox[LLX] = floor(fllx);
+	boundingbox[LLY] = floor(flly);
+	boundingbox[URX] = ceil(furx);
+	boundingbox[URY] = ceil(fury);
+	return 1;
+}
+
 struct document *
-psscan(fileP,filename,filename_raw,filename_dscP,cmd_scan_pdf,filename_uncP,cmd_uncompress,scanstyle,gv_gs_safeDir)
-    FILE **fileP;
-    char *filename;
-    char *filename_raw;
-    char **filename_dscP;
-    char *cmd_scan_pdf;
-    char **filename_uncP;
-    char *cmd_uncompress;
-    int scanstyle;
-    int gv_gs_safeDir;
+psscan(FILE **fileP, char *filename, char *filename_raw, char **filename_dscP, char *cmd_scan_pdf, char **filename_uncP, char *cmd_uncompress, int scanstyle, int gv_gs_safeDir)
 {
     FILE *file;
     struct document *doc;
@@ -353,14 +381,14 @@ psscan(fileP,filename,filename_raw,filename_dscP,cmd_scan_pdf,filename_uncP,cmd_
     int page_media_set = NONE;
     int preread;		/* flag which tells the readline isn't needed */
     int i;
-    unsigned int maxpages = 0;
+    long l;
+    char *p;
+    int maxpages = 0;
     unsigned int nextpage = 1;	/* Next expected page */
     unsigned int thispage;
     int ignore = 0;		/* whether to ignore page ordinals */
     char *label;
     char *line;
-                           	/* 255 characters + 1 newline + 1 NULL */
-    char text[PSLINELENGTH];	/* Temporary storage for text */
     gv_off_t position;		/* Position of the current line */
     gv_off_t beginsection;		/* Position of the beginning of the section */
 
@@ -499,14 +527,13 @@ unc_ok:
     if (line_len>1 && (iscomment(line,"%!PS-Adobe-") || iscomment(line + 1,"%!PS-Adobe-"))) {
       INFMESSAGE(found "PS-Adobe-" comment)
 
-      doc = (struct document *) malloc(sizeof(struct document));
+      doc = (struct document *) calloc(1, sizeof(struct document));
       CHECK_MALLOCED(doc);
-      memset(doc, 0, sizeof(struct document));
-      *text=0;
-      sec_sscanf(line, "%*s %256s", text);
-      /*###jp###*/
-      /*doc->epsf = iscomment(text, "EPSF-");*/
-      doc->epsf = iscomment(text, "EPSF");
+      p = line;
+      while (*p != '\0' && *p != ' ' && *p != '\t')
+	      p++;
+      p = firstword(p);
+      doc->epsf = strncmp(p, "EPSF", 4) == 0;
       doc->beginheader = position;
       section_len = line_len;
     } else if (iscomment(line,"%PDF-") && cmd_scan_pdf) {
@@ -601,16 +628,19 @@ unc_ok:
 	close(tmpfd);
 
         tmp_file = fopen( tmp_filename, "r" );
-	while ( fgets( password_line, 999, tmp_file) )
+        if (tmp_file)
 	{
-	   if (strstr(password_line,"This file requires a password for access."))
-	      found = 1;
-	   if (strstr(password_line,"Password did not work."))
-	      found = 1;
-        }
-	fclose(tmp_file);	
-	unlink((char*) tmp_file);
-	
+	  while ( fgets( password_line, 999, tmp_file) )
+	  {
+	     if (strstr(password_line,"This file requires a password for access."))
+	        found = 1;
+	     if (strstr(password_line,"Password did not work."))
+	        found = 1;
+          }
+	  fclose(tmp_file);
+	  unlink(tmp_filename);
+	}
+
 	if (found)
 	{
 	   cb_askPassword((Widget)NULL, NULL, NULL);
@@ -678,65 +708,41 @@ scan_ok:
 	} else if (doc->date == NULL && iscomment(line+2, "CreationDate:")) {
 	    doc->date = gettextline(line+length("%%CreationDate:"));
 	} else if (bb_set == NONE && iscomment(line+2, "BoundingBox:")) {
-	    sec_sscanf(line+length("%%BoundingBox:"), "%256s", text);
-	    if (strcmp(text, "(atend)") == 0) {
+	    p = firstword(line + length("%%BoundingBox:"));
+	    if (isword(p, "(atend)")) {
 		bb_set = ATEND;
-	    } else {
-		if (sec_sscanf(line+length("%%BoundingBox:"), "%d %d %d %d",
-			   &(doc->boundingbox[LLX]),
-			   &(doc->boundingbox[LLY]),
-			   &(doc->boundingbox[URX]),
-			   &(doc->boundingbox[URY])) == 4)
-		    bb_set = 1;
-		else {
-		    float fllx, flly, furx, fury;
-		    if (sec_sscanf(line+length("%%BoundingBox:"), "%f %f %f %f",
-			       &fllx, &flly, &furx, &fury) == 4) {
-			bb_set = 1;
-			doc->boundingbox[LLX] = fllx;
-			doc->boundingbox[LLY] = flly;
-			doc->boundingbox[URX] = furx;
-			doc->boundingbox[URY] = fury;
-			if (fllx < doc->boundingbox[LLX])
-			    doc->boundingbox[LLX]--;
-			if (flly < doc->boundingbox[LLY])
-			    doc->boundingbox[LLY]--;
-			if (furx > doc->boundingbox[URX])
-			    doc->boundingbox[URX]++;
-			if (fury > doc->boundingbox[URY])
-			    doc->boundingbox[URY]++;
-		    }
-		}
+	    } else if (parse_boundingbox(p, doc->boundingbox)) {
+		bb_set = 1;
 	    }
 	} else if (orientation_set == NONE &&
 		   iscomment(line+2, "Orientation:")) {
-	    sec_sscanf(line+length("%%Orientation:"), "%256s", text);
-	    if (strcmp(text, "(atend)") == 0) {
+	    p = firstword(line + length("%%Orientation:"));
+	    if (isword(p, "(atend)")) {
 		orientation_set = ATEND;
-	    } else if (strcmp(text, "Portrait") == 0) {
+	    } else if (isword(p, "Portrait")) {
 		doc->orientation = PORTRAIT;
 		orientation_set = 1;
-	    } else if (strcmp(text, "Landscape") == 0) {
+	    } else if (isword(p, "Landscape")) {
 		doc->orientation = LANDSCAPE;
 		orientation_set = 1;
 	    }
 	} else if (page_order_set == NONE && iscomment(line+2, "PageOrder:")) {
-	    sec_sscanf(line+length("%%PageOrder:"), "%256s", text);
-	    if (strcmp(text, "(atend)") == 0) {
+	    p = firstword(line + length("%%PageOrder:"));
+	    if (isword(p, "(atend)")) {
 		page_order_set = ATEND;
-	    } else if (strcmp(text, "Ascend") == 0) {
+	    } else if (isword(p, "Ascend")) {
 		doc->pageorder = ASCEND;
 		page_order_set = 1;
-	    } else if (strcmp(text, "Descend") == 0) {
+	    } else if (isword(p, "Descend")) {
 		doc->pageorder = DESCEND;
 		page_order_set = 1;
-	    } else if (strcmp(text, "Special") == 0) {
+	    } else if (isword(p, "Special")) {
 		doc->pageorder = SPECIAL;
 		page_order_set = 1;
 	    }
 	} else if (pages_set == NONE && iscomment(line+2, "Pages:")) {
-	    sec_sscanf(line+length("%%Pages:"), "%256s", text);
-	    if (strcmp(text, "(atend)") == 0) {
+	    p = firstword(line + length("%%Pages:"));
+	    if (isword(p, "(atend)")) {
 		pages_set = ATEND;
 	    } else {
 		switch (sec_sscanf(line+length("%%Pages:"), "%d %d",
@@ -955,10 +961,10 @@ scan_ok:
 		/* Do nothing */
 	    } else if (doc->default_page_orientation == NONE &&
 		iscomment(line+2, "PageOrientation:")) {
-		sec_sscanf(line+length("%%PageOrientation:"), "%256s", text);
-		if (strcmp(text, "Portrait") == 0) {
+		p = firstword(line + length("%%PageOrientation:"));
+		if (isword(p, "Portrait")) {
 		    doc->default_page_orientation = PORTRAIT;
-		} else if (strcmp(text, "Landscape") == 0) {
+		} else if (isword(p, "Landscape")) {
 		    doc->default_page_orientation = LANDSCAPE;
 		}
 	    } else if (page_media_set == NONE &&
@@ -974,31 +980,9 @@ scan_ok:
 		free(cp);
 	    } else if (page_bb_set == NONE &&
 		       iscomment(line+2, "PageBoundingBox:")) {
-		if (sec_sscanf(line+length("%%PageBoundingBox:"), "%d %d %d %d",
-			   &(doc->default_page_boundingbox[LLX]),
-			   &(doc->default_page_boundingbox[LLY]),
-			   &(doc->default_page_boundingbox[URX]),
-			   &(doc->default_page_boundingbox[URY])) == 4)
-		    page_bb_set = 1;
-		else {
-		    float fllx, flly, furx, fury;
-		    if (sec_sscanf(line+length("%%PageBoundingBox:"), "%f %f %f %f",
-			       &fllx, &flly, &furx, &fury) == 4) {
+		p = firstword(line + length("%%PageBoundingBox:"));
+		if (parse_boundingbox(p, doc->default_page_boundingbox))
 			page_bb_set = 1;
-			doc->default_page_boundingbox[LLX] = fllx;
-			doc->default_page_boundingbox[LLY] = flly;
-			doc->default_page_boundingbox[URX] = furx;
-			doc->default_page_boundingbox[URY] = fury;
-			if (fllx < doc->default_page_boundingbox[LLX])
-			    doc->default_page_boundingbox[LLX]--;
-			if (flly < doc->default_page_boundingbox[LLY])
-			    doc->default_page_boundingbox[LLY]--;
-			if (furx > doc->default_page_boundingbox[URX])
-			    doc->default_page_boundingbox[URX]++;
-			if (fury > doc->default_page_boundingbox[URY])
-			    doc->default_page_boundingbox[URY]++;
-		    }
-		}
 	    }
 	}
 	section_len += line_len;
@@ -1077,10 +1061,10 @@ scan_ok:
 		/* Do nothing */
 	    } else if (doc->default_page_orientation == NONE &&
 		iscomment(line+2, "PageOrientation:")) {
-		sec_sscanf(line+length("%%PageOrientation:"), "%256s", text);
-		if (strcmp(text, "Portrait") == 0) {
+		p = firstword(line + length("%%PageOrientation:"));
+		if (isword(p, "Portrait")) {
 		    doc->default_page_orientation = PORTRAIT;
-		} else if (strcmp(text, "Landscape") == 0) {
+		} else if (isword(p, "Landscape")) {
 		    doc->default_page_orientation = LANDSCAPE;
 		}
 	    } else if (page_media_set == NONE &&
@@ -1100,31 +1084,9 @@ scan_ok:
 		free(cp);
 	    } else if (page_bb_set == NONE &&
 		       iscomment(line+2, "PageBoundingBox:")) {
-		if (sec_sscanf(line+length("%%PageBoundingBox:"), "%d %d %d %d",
-			   &(doc->default_page_boundingbox[LLX]),
-			   &(doc->default_page_boundingbox[LLY]),
-			   &(doc->default_page_boundingbox[URX]),
-			   &(doc->default_page_boundingbox[URY])) == 4)
-		    page_bb_set = 1;
-		else {
-		    float fllx, flly, furx, fury;
-		    if (sec_sscanf(line+length("%%PageBoundingBox:"), "%f %f %f %f",
-			       &fllx, &flly, &furx, &fury) == 4) {
+		p = firstword(line + length("%%PageBoundingBox:"));
+		if (parse_boundingbox(p, doc->default_page_boundingbox))
 			page_bb_set = 1;
-			doc->default_page_boundingbox[LLX] = fllx;
-			doc->default_page_boundingbox[LLY] = flly;
-			doc->default_page_boundingbox[URX] = furx;
-			doc->default_page_boundingbox[URY] = fury;
-			if (fllx < doc->default_page_boundingbox[LLX])
-			    doc->default_page_boundingbox[LLX]--;
-			if (flly < doc->default_page_boundingbox[LLY])
-			    doc->default_page_boundingbox[LLY]--;
-			if (furx > doc->default_page_boundingbox[URX])
-			    doc->default_page_boundingbox[URX]++;
-			if (fury > doc->default_page_boundingbox[URY])
-			    doc->default_page_boundingbox[URY]++;
-		    }
-		}
 	    }
 	}
 	section_len += line_len;
@@ -1176,7 +1138,8 @@ newpage:
             CHECK_MALLOCED(doc->pages);
 	}
 	label = ps_gettext(line+length("%%Page:"), &next_char);
-	if (sec_sscanf(next_char, "%d", &thispage) != 1) thispage = 0;
+	l = atol(firstword(next_char));
+	thispage = (l > 0)?l:0;
 	if (nextpage == 1) {
 	    ignore = thispage != 1;
 	}
@@ -1214,10 +1177,10 @@ continuepage:
 		/* Do nothing */
 	    } else if (doc->pages[doc->numpages].orientation == NONE &&
 		iscomment(line+2, "PageOrientation:")) {
-		sec_sscanf(line+length("%%PageOrientation:"), "%256s", text);
-		if (strcmp(text, "Portrait") == 0) {
+		p = firstword(line + length("%%PageOrientation:"));
+		if (isword(p, "Portrait")) {
 		    doc->pages[doc->numpages].orientation = PORTRAIT;
-		} else if (strcmp(text, "Landscape") == 0) {
+		} else if (isword(p, "Landscape")) {
 		    doc->pages[doc->numpages].orientation = LANDSCAPE;
 		}
 	    } else if (doc->pages[doc->numpages].media == NULL &&
@@ -1246,42 +1209,11 @@ continuepage:
 		free(cp);
 	    } else if ((page_bb_set == NONE || page_bb_set == ATEND) &&
 		       iscomment(line+2, "PageBoundingBox:")) {
-		sec_sscanf(line+length("%%PageBoundingBox:"), "%256s", text);
-		if (strcmp(text, "(atend)") == 0) {
+		p = firstword(line + length("%%PageBoundingBox:"));
+		if (isword(p, "(atend)")) {
 		    page_bb_set = ATEND;
-		} else {
-		    if (sec_sscanf(line+length("%%PageBoundingBox:"), "%d %d %d %d",
-			    &(doc->pages[doc->numpages].boundingbox[LLX]),
-			    &(doc->pages[doc->numpages].boundingbox[LLY]),
-			    &(doc->pages[doc->numpages].boundingbox[URX]),
-			    &(doc->pages[doc->numpages].boundingbox[URY])) == 4) 
-		      {
+		} else if (parse_boundingbox(p, doc->pages[doc->numpages].boundingbox)) {
 			if (page_bb_set == NONE) page_bb_set = 1;
-		      }
-		    else {
-			float fllx, flly, furx, fury;
-			if (sec_sscanf(line+length("%%PageBoundingBox:"),
-				   "%f %f %f %f",
-				   &fllx, &flly, &furx, &fury) == 4) {
-			    if (page_bb_set == NONE) page_bb_set = 1;
-			    doc->pages[doc->numpages].boundingbox[LLX] = fllx;
-			    doc->pages[doc->numpages].boundingbox[LLY] = flly;
-			    doc->pages[doc->numpages].boundingbox[URX] = furx;
-			    doc->pages[doc->numpages].boundingbox[URY] = fury;
-			    if (fllx <
-				    doc->pages[doc->numpages].boundingbox[LLX])
-				doc->pages[doc->numpages].boundingbox[LLX]--;
-			    if (flly <
-				    doc->pages[doc->numpages].boundingbox[LLY])
-				doc->pages[doc->numpages].boundingbox[LLY]--;
-			    if (furx >
-				    doc->pages[doc->numpages].boundingbox[URX])
-				doc->pages[doc->numpages].boundingbox[URX]++;
-			    if (fury >
-				    doc->pages[doc->numpages].boundingbox[URY])
-				doc->pages[doc->numpages].boundingbox[URY]++;
-			}
-		    }
 		}
 	    }
 	}
@@ -1311,7 +1243,8 @@ continuepage:
 	    /* Do nothing */
 	} else if (iscomment(line+2, "Page:")) {
 	    free(ps_gettext(line+length("%%Page:"), &next_char));
-	    if (sec_sscanf(next_char, "%d", &thispage) != 1) thispage = 0;
+	    l = atol(firstword(next_char));
+	    thispage = (l > 0)?l:0;
 	    if (!ignore && thispage == nextpage) {
 		if (doc->numpages > 0) {
 		    doc->pages[doc->numpages-1].end = position;
@@ -1338,43 +1271,23 @@ continuepage:
 	    doc->begintrailer = position;
 	    section_len = line_len;
 	} else if (bb_set == ATEND && iscomment(line+2, "BoundingBox:")) {
-	    if (sec_sscanf(line+length("%%BoundingBox:"), "%d %d %d %d",
-		       &(doc->boundingbox[LLX]),
-		       &(doc->boundingbox[LLY]),
-		       &(doc->boundingbox[URX]),
-		       &(doc->boundingbox[URY])) != 4) {
-		float fllx, flly, furx, fury;
-		if (sec_sscanf(line+length("%%BoundingBox:"), "%f %f %f %f",
-			   &fllx, &flly, &furx, &fury) == 4) {
-		    doc->boundingbox[LLX] = fllx;
-		    doc->boundingbox[LLY] = flly;
-		    doc->boundingbox[URX] = furx;
-		    doc->boundingbox[URY] = fury;
-		    if (fllx < doc->boundingbox[LLX])
-			doc->boundingbox[LLX]--;
-		    if (flly < doc->boundingbox[LLY])
-			doc->boundingbox[LLY]--;
-		    if (furx > doc->boundingbox[URX])
-			doc->boundingbox[URX]++;
-		    if (fury > doc->boundingbox[URY])
-			doc->boundingbox[URY]++;
-		}
-	    }
+		p = firstword(line + length("%%BoundingBox:"));
+		(void)parse_boundingbox(p, doc->boundingbox);
 	} else if (orientation_set == ATEND &&
 		   iscomment(line+2, "Orientation:")) {
-	    sec_sscanf(line+length("%%Orientation:"), "%256s", text);
-	    if (strcmp(text, "Portrait") == 0) {
+	    p = firstword(line + length("%%Orientation:"));
+	    if (isword(p, "Portrait")) {
 		doc->orientation = PORTRAIT;
-	    } else if (strcmp(text, "Landscape") == 0) {
+	    } else if (isword(p, "Landscape")) {
 		doc->orientation = LANDSCAPE;
 	    }
 	} else if (page_order_set == ATEND && iscomment(line+2, "PageOrder:")) {
-	    sec_sscanf(line+length("%%PageOrder:"), "%256s", text);
-	    if (strcmp(text, "Ascend") == 0) {
+	    p = firstword(line + length("%%PageOrder:"));
+	    if (isword(p, "Ascend")) {
 		doc->pageorder = ASCEND;
-	    } else if (strcmp(text, "Descend") == 0) {
+	    } else if (isword(p, "Descend")) {
 		doc->pageorder = DESCEND;
-	    } else if (strcmp(text, "Special") == 0) {
+	    } else if (isword(p, "Special")) {
 		doc->pageorder = SPECIAL;
 	    }
 	} else if (pages_set == ATEND && iscomment(line+2, "Pages:")) {
@@ -1438,8 +1351,7 @@ continuepage:
 /*###########################################################*/
 
 void
-psfree(doc)
-    struct document *doc;
+psfree(struct document *doc)
 {
     int i;
 
@@ -1469,8 +1381,7 @@ psfree(doc)
 /*----------------------------------------------------------*/
 
 static char *
-gettextline(line)
-    char *line;
+gettextline(char *line)
 {
     char *cp;
 
@@ -1498,9 +1409,7 @@ gettextline(line)
 /*----------------------------------------------------------*/
 
 static char *
-ps_gettext(line, next_char)
-    char *line;
-    char **next_char;
+ps_gettext(char *line, char **next_char)
 {
     char text[PSLINELENGTH];	/* Temporary storage for text */
     char *cp;
@@ -1615,8 +1524,7 @@ ps_gettext(line, next_char)
 #define MAX_PS_IO_FGETCHARS_BUF_SIZE 57344
 #define BREAK_PS_IO_FGETCHARS_BUF_SIZE 49152
 
-static FileData ps_io_init(file)
-   FILE *file;
+static FileData ps_io_init(FILE *file)
 {
    FileData fd;
    Cardinal size = sizeof(FileDataStruct);
@@ -1642,8 +1550,7 @@ static FileData ps_io_init(file)
 /*----------------------------------------------------------*/
 
 static void
-ps_io_exit(fd)
-   FileData fd;
+ps_io_exit(FileData fd)
 {
    BEGINMESSAGE(ps_io_exit)
    XtFree(FD_BUF);
@@ -1656,9 +1563,7 @@ ps_io_exit(fd)
 /*----------------------------------------------------------*/
 
 static int
-ps_io_fseek(fd,offset)
-   FileData fd;
-   gv_off_t offset;
+ps_io_fseek(FileData fd, gv_off_t offset)
 {
    int status;
    BEGINMESSAGE(ps_io_fseek)
@@ -1675,8 +1580,7 @@ ps_io_fseek(fd,offset)
 /*----------------------------------------------------------*/
 
 static gv_off_t
-ps_io_ftell(fd)
-   FileData fd;
+ps_io_ftell(FileData fd)
 {
    BEGINMESSAGE(ps_io_ftell)
    IMESSAGE(FD_FILEPOS)
@@ -1689,10 +1593,7 @@ ps_io_ftell(fd)
 /*----------------------------------------------------------*/
 
 #ifdef USE_MEMMOVE_CODE
-static void ps_memmove (d, s, l)
-  char *d;
-  const char *s;
-  unsigned l;
+static void ps_memmove (char *d, const char *s, unsigned l)
 {
   if (s < d) for (s += l, d += l; l; --l) *--d = *--s;
   else if (s != d) for (; l; --l)         *d++ = *s++;
@@ -1701,9 +1602,7 @@ static void ps_memmove (d, s, l)
 #   define ps_memmove memmove
 #endif
 
-static char * ps_io_fgetchars(fd,num)
-   FileData fd;
-   int num;
+static char * ps_io_fgetchars(FileData fd, int num)
 {
    char *eol=NULL,*tmp;
    size_t size_of_char = sizeof(char);
@@ -1830,11 +1729,7 @@ static char * ps_io_fgetchars(fd,num)
 */
 /*----------------------------------------------------------*/
 
-static char * readline (fd, lineP, positionP, line_lenP)
-   FileData fd;
-   char **lineP;
-   gv_off_t *positionP;
-   unsigned int *line_lenP;
+static char * readline(FileData fd, char **lineP, gv_off_t *positionP, unsigned int *line_lenP)
 {
    unsigned int nbytes=0;
    int skipped=0;
@@ -1925,7 +1820,7 @@ static char * readline (fd, lineP, positionP, line_lenP)
       INFMESSAGE(encountered "BeginData:")
       if (FD_LINE_LEN > 100) FD_BUF[100] = '\0';
       text[0] = '\0';
-      if (sec_sscanf(line+length("%%BeginData:"), "%d %*s %100s", &num, text) >= 1) {
+      if (sec_sscanf(line+length("%%BeginData:"), "%d %*s %100s", &num, text, 100) >= 1) {
          if (strcmp(text, "Lines") == 0) {
             INFIMESSAGE(number of lines to skip:,num)
             while (num) {
@@ -1985,12 +1880,8 @@ static char * readline (fd, lineP, positionP, line_lenP)
 /*###########################################################*/
 
 char *
-pscopyuntil(fd, to, begin, end, comment)
-   FileData fd;
-   FILE *to;
-   long begin;			/* set negative to avoid initial seek */
-   long end;
-   char *comment;
+pscopyuntil(FileData fd, FILE *to, long begin, long end, char *comment)
+   /* begin: set negative to avoid initial seek */
 {
    char *line;
    int comment_length;
@@ -2024,7 +1915,7 @@ pscopyuntil(fd, to, begin, end, comment)
          INFMESSAGE(encountered "BeginData:")
          if (FD_LINE_LEN > 100) FD_BUF[100] = '\0';
          text[0] = '\0';
-         if (sec_sscanf(line+length("%%BeginData:"), "%d %*s %100s", &num, text) >= 1) {
+         if (sec_sscanf(line+length("%%BeginData:"), "%d %*s %100s", &num, text, 100) >= 1) {
             if (strcmp(text, "Lines") == 0) {
                INFIMESSAGE(number of lines:,num)
                while (num) {
@@ -2068,8 +1959,7 @@ pscopyuntil(fd, to, begin, end, comment)
 /* Check whether the line contains nothing but white space. */
 /*----------------------------------------------------------*/
 
-static int blank(line)
-   char *line;
+static int blank(char *line)
 {
    char *cp = line;
 
@@ -2085,14 +1975,9 @@ static int blank(line)
 /*##########################################################*/
 
 void
-pscopydoc(dest_file,src_filename,d,pagelist)
-    FILE *dest_file;
-    char *src_filename;
-    Document d;
-    char *pagelist;
+pscopydoc(FILE *dest_file, char *src_filename, Document d, char *pagelist)
 {
     FILE *src_file;
-    char text[PSLINELENGTH];
     char *comment;
     Boolean pages_written = False;
     Boolean pages_atend = False;
@@ -2101,6 +1986,7 @@ pscopydoc(dest_file,src_filename,d,pagelist)
     int i, j;
     int here;
     FileData fd;
+    char *p;
 
     BEGINMESSAGE(pscopydoc)
 
@@ -2121,12 +2007,12 @@ pscopydoc(dest_file,src_filename,d,pagelist)
           free(comment);
           continue;
        }
-       sec_sscanf(comment+length("%%Pages:"), "%256s", text);
-       if (strcmp(text, "(atend)") == 0) {
+       p = firstword(comment + length("%%Pages:"));
+       if (isword(p, "(atend)")) {
           fputs(comment, dest_file);
           pages_atend = True;
        } else {
-          switch (sec_sscanf(comment+length("%%Pages:"), "%*d %d", &i)) {
+          switch (sec_sscanf(p, "%*d %d", &i)) {
              case 1:
                 fprintf(dest_file, "%%%%Pages: %d %d\n", pages, i);
                 break;
